@@ -14,24 +14,28 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use std::fmt;
-use std::fmt::Write;
-use std::iter::FromIterator;
+use std::{
+    fmt,
+    fmt::Write,
+    iter::{FromIterator, FusedIterator},
+};
 
-use crate::attacks;
-use crate::bitboard::Bitboard;
-use crate::color::{Color, ByColor};
-use crate::square::{File, Rank, Square};
-use crate::types::{Piece, Role};
-use crate::material::{Material, MaterialSide};
+use crate::{
+    attacks,
+    bitboard::Bitboard,
+    color::{ByColor, Color},
+    material::{Material, MaterialSide},
+    square::{File, Rank, Square},
+    types::{Piece, Role},
+};
 
 /// [`Piece`] positions on a board.
 ///
 /// # Examples
 ///
 /// ```
-/// # use shakmaty::{Square, Board};
-/// # use shakmaty::Color::Black;
+/// use shakmaty::{Square, Board, Color::Black};
+///
 /// let board = Board::new();
 /// // r n b q k b n r
 /// // p p p p p p p p
@@ -113,37 +117,63 @@ impl Board {
     }
 
     #[inline]
-    pub fn occupied(&self) -> Bitboard { self.occupied[0] }
+    pub fn occupied(&self) -> Bitboard {
+        self.occupied[0]
+    }
 
     #[inline]
-    pub fn pawns(&self)   -> Bitboard { self.occupied[Role::Pawn as usize] }
+    pub fn pawns(&self) -> Bitboard {
+        self.occupied[Role::Pawn as usize]
+    }
     #[inline]
-    pub fn knights(&self) -> Bitboard { self.occupied[Role::Knight as usize] }
+    pub fn knights(&self) -> Bitboard {
+        self.occupied[Role::Knight as usize]
+    }
     #[inline]
-    pub fn bishops(&self) -> Bitboard { self.occupied[Role::Bishop as usize] }
+    pub fn bishops(&self) -> Bitboard {
+        self.occupied[Role::Bishop as usize]
+    }
     #[inline]
-    pub fn rooks(&self)   -> Bitboard { self.occupied[Role::Rook as usize] }
+    pub fn rooks(&self) -> Bitboard {
+        self.occupied[Role::Rook as usize]
+    }
     #[inline]
-    pub fn queens(&self)  -> Bitboard { self.occupied[Role::Queen as usize] }
+    pub fn queens(&self) -> Bitboard {
+        self.occupied[Role::Queen as usize]
+    }
     #[inline]
-    pub fn kings(&self)   -> Bitboard { self.occupied[Role::King as usize] }
+    pub fn kings(&self) -> Bitboard {
+        self.occupied[Role::King as usize]
+    }
 
     #[inline]
-    pub fn white(&self) -> Bitboard { self.occupied_co.white }
+    pub fn white(&self) -> Bitboard {
+        self.occupied_co.white
+    }
     #[inline]
-    pub fn black(&self) -> Bitboard { self.occupied_co.black }
+    pub fn black(&self) -> Bitboard {
+        self.occupied_co.black
+    }
 
     /// Bishops, rooks and queens.
     #[inline]
-    pub fn sliders(&self) -> Bitboard { self.bishops() ^ self.rooks() ^ self.queens() }
+    pub fn sliders(&self) -> Bitboard {
+        self.bishops() ^ self.rooks() ^ self.queens()
+    }
     /// Pawns, knights and kings.
     #[inline]
-    pub fn steppers(&self) -> Bitboard { self.pawns() ^ self.knights() ^ self.kings() }
+    pub fn steppers(&self) -> Bitboard {
+        self.pawns() ^ self.knights() ^ self.kings()
+    }
 
     #[inline]
-    pub fn rooks_and_queens(&self) -> Bitboard { self.rooks() ^ self.queens() }
+    pub fn rooks_and_queens(&self) -> Bitboard {
+        self.rooks() ^ self.queens()
+    }
     #[inline]
-    pub fn bishops_and_queens(&self) -> Bitboard { self.bishops() ^ self.queens() }
+    pub fn bishops_and_queens(&self) -> Bitboard {
+        self.bishops() ^ self.queens()
+    }
 
     /// The (unique) king of the given side.
     #[inline]
@@ -254,12 +284,12 @@ impl Board {
 
     #[inline]
     pub fn attacks_to(&self, sq: Square, attacker: Color, occupied: Bitboard) -> Bitboard {
-        self.by_color(attacker) & (
-            (attacks::rook_attacks(sq, occupied) & self.rooks_and_queens()) |
-            (attacks::bishop_attacks(sq, occupied) & self.bishops_and_queens()) |
-            (attacks::knight_attacks(sq) & self.knights()) |
-            (attacks::king_attacks(sq) & self.kings()) |
-            (attacks::pawn_attacks(!attacker, sq) & self.pawns()))
+        self.by_color(attacker)
+            & ((attacks::rook_attacks(sq, occupied) & self.rooks_and_queens())
+                | (attacks::bishop_attacks(sq, occupied) & self.bishops_and_queens())
+                | (attacks::knight_attacks(sq) & self.knights())
+                | (attacks::king_attacks(sq) & self.kings())
+                | (attacks::pawn_attacks(!attacker, sq) & self.pawns()))
     }
 
     pub fn pieces(&self) -> Pieces {
@@ -303,7 +333,7 @@ impl Default for Board {
 
 impl fmt::Debug for Board {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        for rank in IntoIterator::into_iter(Rank::ALL).rev() {
+        for rank in Rank::ALL.into_iter().rev() {
             for file in File::ALL {
                 let square = Square::from_coords(file, rank);
                 f.write_char(self.piece_at(square).map_or('.', Piece::char))?;
@@ -356,25 +386,23 @@ impl Iterator for Pieces {
     type Item = (Square, Piece);
 
     fn next(&mut self) -> Option<(Square, Piece)> {
-        if let Some(sq) = self.pawns.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).pawn())));
-        }
-        if let Some(sq) = self.knights.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).knight())));
-        }
-        if let Some(sq) = self.bishops.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).bishop())));
-        }
-        if let Some(sq) = self.rooks.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).rook())));
-        }
-        if let Some(sq) = self.queens.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).queen())));
-        }
-        if let Some(sq) = self.kings.pop_front() {
-            return Some((sq, (Color::from_white(self.white.contains(sq)).king())));
-        }
-        None
+        let (sq, role) = if let Some(sq) = self.pawns.pop_front() {
+            (sq, Role::Pawn)
+        } else if let Some(sq) = self.knights.pop_front() {
+            (sq, Role::Knight)
+        } else if let Some(sq) = self.bishops.pop_front() {
+            (sq, Role::Bishop)
+        } else if let Some(sq) = self.rooks.pop_front() {
+            (sq, Role::Rook)
+        } else if let Some(sq) = self.queens.pop_front() {
+            (sq, Role::Queen)
+        } else if let Some(sq) = self.kings.pop_front() {
+            (sq, Role::King)
+        } else {
+            return None;
+        };
+
+        Some((sq, role.of(Color::from_white(self.white.contains(sq)))))
     }
 
     fn count(self) -> usize {
@@ -389,12 +417,16 @@ impl Iterator for Pieces {
 
 impl ExactSizeIterator for Pieces {
     fn len(&self) -> usize {
-        self.pawns.count() + self.knights.count() + self.bishops.count()
-            + self.rooks.count() + self.queens.count() + self.kings.count()
+        self.pawns.count()
+            + self.knights.count()
+            + self.bishops.count()
+            + self.rooks.count()
+            + self.queens.count()
+            + self.kings.count()
     }
 }
 
-impl ::std::iter::FusedIterator for Pieces {}
+impl FusedIterator for Pieces {}
 
 #[cfg(test)]
 mod tests {
