@@ -31,7 +31,6 @@
 //! Play moves:
 //!
 //! ```
-//! # use std::error::Error;
 //! # use shakmaty::{Chess, Position};
 //! use shakmaty::{Square, Move, Role};
 //! #
@@ -45,8 +44,7 @@
 //!     capture: None,
 //!     promotion: None,
 //! })?;
-//! #
-//! # Ok::<_, Box<dyn Error>>(())
+//! # Ok::<_, Box<dyn std::error::Error>>(())
 //! ```
 //!
 //! Detect game end conditions:
@@ -70,44 +68,44 @@
 //! * `step`: Implements [`std::iter::Step`] for `Square`, `File`, and `Rank`.
 //!   Requires nightly.
 
-#![doc(html_root_url = "https://docs.rs/shakmaty/0.20.1")]
-
+#![doc(html_root_url = "https://docs.rs/shakmaty/0.20.2")]
 #![forbid(unsafe_op_in_unsafe_fn)]
 #![warn(missing_debug_implementations)]
-
 #![cfg_attr(feature = "step", feature(step_trait))]
 #![cfg_attr(docs_rs, feature(doc_cfg))]
 
-mod color;
-mod square;
-mod types;
-mod material;
 mod board;
+mod color;
+mod magics;
+mod material;
+mod movelist;
+mod perft;
 mod position;
 mod setup;
-mod movelist;
-mod magics;
-mod perft;
+mod square;
+mod types;
 mod util;
 
 pub mod attacks;
 pub mod bitboard;
 pub mod fen;
-pub mod uci;
 pub mod san;
+pub mod uci;
 pub mod zobrist;
 
 #[cfg(feature = "variant")]
 #[cfg_attr(docs_rs, doc(cfg(feature = "variant")))]
 pub mod variant;
 
-pub use crate::square::{ParseSquareError, File, Rank, Square};
-pub use crate::color::{ParseColorError, Color, ByColor, ByColorIter};
-pub use crate::types::{CastlingSide, CastlingMode, Move, Piece, Role, RemainingChecks};
-pub use crate::material::{Material, MaterialSide, ParseMaterialError};
-pub use crate::bitboard::Bitboard;
-pub use crate::board::{Board, Pieces};
-pub use crate::setup::{Castles, Setup};
-pub use crate::movelist::MoveList;
-pub use crate::position::{Chess, Outcome, Position, FromSetup, PlayError, PositionError, PositionErrorKinds};
-pub use crate::perft::perft;
+pub use crate::{
+    bitboard::Bitboard,
+    board::{Board, Pieces},
+    color::{ByColor, ByColorIter, Color, ParseColorError},
+    material::{Material, MaterialSide, ParseMaterialError},
+    movelist::MoveList,
+    perft::perft,
+    position::{Chess, FromSetup, Outcome, PlayError, Position, PositionError, PositionErrorKinds},
+    setup::{Castles, Setup},
+    square::{File, ParseSquareError, Rank, Square},
+    types::{CastlingMode, CastlingSide, Move, Piece, RemainingChecks, Role},
+};
