@@ -14,13 +14,16 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-use std::cmp::max;
-use std::convert::TryInto;
-use std::num::TryFromIntError;
-use std::fmt::{self, Write as _};
-use std::str;
-use std::error::Error;
-use std::ops::Sub;
+use std::{
+    cmp::max,
+    convert::TryInto,
+    error::Error,
+    fmt::{self, Write as _},
+    mem,
+    num::TryFromIntError,
+    ops::Sub,
+    str,
+};
 
 use crate::util::overflow_error;
 
@@ -65,12 +68,16 @@ macro_rules! unsafe_step_impl {
 
             fn forward_checked(start: Self, count: usize) -> Option<Self> {
                 use std::convert::TryFrom as _;
-                i32::try_from(count).ok().and_then(|count| start.offset(count))
+                i32::try_from(count)
+                    .ok()
+                    .and_then(|count| start.offset(count))
             }
 
             fn backward_checked(start: Self, count: usize) -> Option<Self> {
                 use std::convert::TryFrom as _;
-                i32::try_from(count).ok().and_then(|count| start.offset(-count))
+                i32::try_from(count)
+                    .ok()
+                    .and_then(|count| start.offset(-count))
             }
 
             unsafe fn forward_unchecked(start: Self, count: usize) -> Self {
@@ -81,7 +88,7 @@ macro_rules! unsafe_step_impl {
                 unsafe { Self::new_unchecked(u32::from(start) - count as u32) }
             }
         }
-    }
+    };
 }
 
 /// A file of the chessboard.
@@ -89,7 +96,14 @@ macro_rules! unsafe_step_impl {
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 #[repr(u8)]
 pub enum File {
-    A = 0, B, C, D, E, F, G, H
+    A = 0,
+    B,
+    C,
+    D,
+    E,
+    F,
+    G,
+    H,
 }
 
 impl File {
@@ -113,10 +127,9 @@ impl File {
     #[inline]
     pub unsafe fn new_unchecked(index: u32) -> File {
         debug_assert!(index < 8);
-        unsafe { ::std::mem::transmute(index as u8) }
+        unsafe { mem::transmute(index as u8) }
     }
 
-
     #[inline]
     pub fn from_char(ch: char) -> Option<File> {
         if ('a'..='h').contains(&ch) {
@@ -139,7 +152,9 @@ impl File {
     #[must_use]
     #[inline]
     pub fn offset(self, delta: i32) -> Option<File> {
-        i32::from(self).checked_add(delta).and_then(|index| index.try_into().ok())
+        i32::from(self)
+            .checked_add(delta)
+            .and_then(|index| index.try_into().ok())
     }
 
     #[must_use]
@@ -161,7 +176,16 @@ impl File {
     }
 
     /// `A`, ..., `H`.
-    pub const ALL: [File; 8] = [File::A, File::B, File::C, File::D, File::E, File::F, File::G, File::H];
+    pub const ALL: [File; 8] = [
+        File::A,
+        File::B,
+        File::C,
+        File::D,
+        File::E,
+        File::F,
+        File::G,
+        File::H,
+    ];
 }
 
 impl Sub for File {
@@ -188,7 +212,14 @@ unsafe_step_impl! { File }
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 #[repr(u8)]
 pub enum Rank {
-    First = 0, Second, Third, Fourth, Fifth, Sixth, Seventh, Eighth
+    First = 0,
+    Second,
+    Third,
+    Fourth,
+    Fifth,
+    Sixth,
+    Seventh,
+    Eighth,
 }
 
 impl Rank {
@@ -212,7 +243,7 @@ impl Rank {
     #[inline]
     pub unsafe fn new_unchecked(index: u32) -> Rank {
         debug_assert!(index < 8);
-        unsafe { ::std::mem::transmute(index as u8) }
+        unsafe { mem::transmute(index as u8) }
     }
 
     #[inline]
@@ -232,7 +263,9 @@ impl Rank {
     #[must_use]
     #[inline]
     pub fn offset(self, delta: i32) -> Option<Rank> {
-        i32::from(self).checked_add(delta).and_then(|index| index.try_into().ok())
+        i32::from(self)
+            .checked_add(delta)
+            .and_then(|index| index.try_into().ok())
     }
 
     #[must_use]
@@ -298,6 +331,7 @@ impl fmt::Display for ParseSquareError {
 impl Error for ParseSquareError {}
 
 /// A square index.
+#[rustfmt::skip]
 #[allow(missing_docs)]
 #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 #[repr(u8)]
@@ -341,7 +375,7 @@ impl Square {
     #[inline]
     pub unsafe fn new_unchecked(index: u32) -> Square {
         debug_assert!(index < 64);
-        unsafe { ::std::mem::transmute(index as u8) }
+        unsafe { mem::transmute(index as u8) }
     }
 
     /// Tries to get a square from file and rank.
@@ -380,7 +414,10 @@ impl Square {
     #[inline]
     pub fn from_ascii(s: &[u8]) -> Result<Square, ParseSquareError> {
         if s.len() == 2 {
-            match (File::from_char(char::from(s[0])), Rank::from_char(char::from(s[1]))) {
+            match (
+                File::from_char(char::from(s[0])),
+                Rank::from_char(char::from(s[1])),
+            ) {
                 (Some(file), Some(rank)) => Ok(Square::from_coords(file, rank)),
                 _ => Err(ParseSquareError),
             }
@@ -449,7 +486,9 @@ impl Square {
     #[must_use]
     #[inline]
     pub fn offset(self, delta: i32) -> Option<Square> {
-        i32::from(self).checked_add(delta).and_then(|index| index.try_into().ok())
+        i32::from(self)
+            .checked_add(delta)
+            .and_then(|index| index.try_into().ok())
     }
 
     /// Flip the square horizontally.
@@ -594,8 +633,10 @@ impl Square {
     /// assert_eq!(Square::A2.distance(Square::B5), 3);
     /// ```
     pub fn distance(self, other: Square) -> u32 {
-        max((self.file() - other.file()).abs(),
-            (self.rank() - other.rank()).abs()) as u32
+        max(
+            (self.file() - other.file()).unsigned_abs(),
+            (self.rank() - other.rank()).unsigned_abs(),
+        )
     }
 }
 
@@ -603,6 +644,7 @@ mod all_squares {
     use super::Square::{self, *};
     impl Square {
         /// `A1`, `B1`, ..., `G8`, `H8`.
+        #[rustfmt::skip]
         pub const ALL: [Square; 64] = [
             A1, B1, C1, D1, E1, F1, G1, H1,
             A2, B2, C2, D2, E2, F2, G2, H2,
